======================
 Invenio-Pages v0.1.2
======================

Invenio-Pages v0.1.2 was released on October 7, 2015.

About
-----

Invenio module that adds support for static pages.

*This is an experimental developer preview release.*

Bug fixes
---------

- Removes calls to PluginManager consider_setuptools_entrypoints()
  removed in PyTest 2.8.0.
- Adds missing `invenio_base` dependency.

Installation
------------

   $ pip install invenio-pages==0.1.2

Documentation
-------------

   http://invenio-pages.readthedocs.org/en/v0.1.2

Happy hacking and thanks for flying Invenio-Pages.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-pages
|   URL: http://invenio-software.org
